{*******************************************************************************
  unit                 ImgBtn.pas

  Version              1.00,   1997-1998;

  Description:         TImgBtn - easy to use button component for multimedia
                       application with different Up, Down, Over and Disabled
                       state pictures. Pictures for different states must be
                       loaded in design or run time Picture, OverPict,
                       DownPict, UpPict, DisPict properties. Dont forget to
                       set Enabled property to TRUE. This button supports
                       all TImage properties, such as Stretch, Transparent etc.

  Compiler:            Delphi 3, 2, 4 (may be 1 and 5, I have not tryed)

  Conditions of usage  Freeware, use at own risk. Please report faults or
                       comments to the authors. If you wish to support the
                       authors somehow, drop me a letter.

  Author               Urry Crashnikov, Andrew Efimoff
                       Media Programming Group
                       mpg@aport.ru,
                       zavr@gmx.net,
                       http://programmer.da.ru

  Installation -       put files ImgBtn.pas and ImgBtn.dcr in your directory
		       for additional components and install ImgBtn.pas unit.
********************************************************************************}



unit ImgBtn;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls;

type
  TImgBtn = class(TImage)
  private
    { Private declarations }
    FOverPict: TPicture;
    FDownPict: TPicture;
    FUpPict:   TPicture;
    FDisPict:  TPicture;
    FEnabled: Boolean;
    Down: Boolean;
    procedure SetOverPict(Value: TPicture);
    procedure SetDownPict(Value: TPicture);
    procedure SetUpPict(Value: TPicture);
    procedure SetDisPict(Value: TPicture);

  public
    { Public declarations }
    destructor Destroy; override;
    procedure MouseDown(Button: TMouseButton; Shift: TShiftState;
      X, Y: Integer); override;
    procedure MouseMove(Shift: TShiftState; X, Y: Integer); override;
    procedure MouseUp(Button: TMouseButton; Shift: TShiftState; X, Y: Integer); override;
    constructor Create(AOwner: TComponent); override;
    procedure SetEnabled(Value: Boolean);  override;
  published
    { Published declarations }
    property OverPict: TPicture read FOverPict write SetOverPict;
    property DownPict: TPicture read FDownPict write SetDownPict;
    property UpPict: TPicture read FUpPict write SetUpPict;
    property DisPict: TPicture read FDisPict write SetDisPict;
    property Enabled: Boolean read FEnabled write SetEnabled;
  end;

procedure Register;

implementation
 
procedure Register;
begin
  RegisterComponents('MPG', [TImgBtn]);
end;

procedure TImgBtn.SetEnabled(Value: Boolean);
begin
 if Value = True then
  Picture:=FUpPict
 else Picture:=FDisPict;
 FEnabled:=Value;
end;

constructor TImgBtn.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FOverPict:= TPicture.Create;
  FDownPict:= TPicture.Create;
  FUpPict := TPicture.Create;
  FDisPict := TPicture.Create;
  picture:= FUpPict;
  Down:= False;
  SetEnabled(Enabled);
end;

procedure TImgBtn.SetOverPict(Value: TPicture);
begin
  FOverPict.Assign(Value);
end;

procedure TImgBtn.SetDownPict(Value: TPicture);
begin
  FDownPict.Assign(Value);
end;

procedure TImgBtn.SetDisPict(Value: TPicture);
begin
  FDisPict.Assign(Value);
end;

procedure TImgBtn.SetUpPict(Value: TPicture);
begin
  FUpPict.Assign(Value);
end;

procedure TImgBtn.MouseMove(Shift: TShiftState; X, Y: Integer);
begin
 inherited;
 if FEnabled=True then
 if not Down then
  if (X<0)or(X>Width)or(Y<0)or(Y>Height) then
   begin
    SetCaptureControl(nil);
    Picture:=FUpPict;
   end  else
   begin
    SetCaptureControl(Self);
    Picture:=FOverPict;
   end; 
end;

procedure TImgBtn.MouseDown(Button: TMouseButton; Shift: TShiftState;
      X, Y: Integer);
begin
 if (Button=mbLeft)and(FEnabled=True) then
  begin
   Picture:=DownPict;
   Down:=True;
  end;
 inherited MouseDown(Button, Shift, X, Y);
end;

procedure TImgBtn.MouseUp(Button: TMouseButton; Shift: TShiftState;
     X, Y: Integer);
begin
 if (Button=mbLeft)and(Enabled=True) then
  begin
   Picture:=UpPict;
   SetCaptureControl(nil);
  end;
 inherited  MouseUp(Button, Shift, X, Y);
 Down:=False;
end;

destructor TImgBtn.Destroy;
begin
  FOverPict.Free;
  FDownPict.Free;
  FUpPict.Free;
  FDisPict.Free;
  inherited Destroy;
end;

end.
